# transcriptioner

A simple interactive tool to assist human transcribers.
Using [vite](https://vite.dev/) and [wavesurfer](https://wavesurfer.xyz/).
Demo file from BABEL dataset.

## See it in action

```sh
npm install
npm run dev
```
